==> constructorio-ui-quizzes-1.4.0.tgz: package/lib/mjs/hooks/usePropsGetters/index.js <==
import { useCallback } from 'react';
import useSelectInputProps from './useSelectInputProps';
import useCoverQuestionProps from './useCoverQuestionProps';
import useOpenTextInputProps from './useOpenTextInputProps';
import useNextQuestionButtonProps from './useNextQuestionButtonProps';
import usePreviousQuestionButtonProps from './usePreviousQuestionButtonProps';
const usePropsGetters = (quizEvents, quizApiState, quizLocalState) => {
    const { quizAnswerChanged, nextQuestion, previousQuestion, resetQuiz, hydrateQuiz, addToCart, resultClick, } = quizEvents;
    const getOpenTextInputProps = useOpenTextInputProps(quizAnswerChanged, nextQuestion, quizApiState.quizCurrentQuestion?.next_question, quizLocalState.answerInputs);
    const getCoverQuestionProps = useCoverQuestionProps(quizAnswerChanged, quizApiState.quizCurrentQuestion?.next_question);
    const getSelectInputProps = useSelectInputProps(quizAnswerChanged, nextQuestion, quizApiState.quizCurrentQuestion?.next_question, quizLocalState.answerInputs);
    const getNextQuestionButtonProps = useNextQuestionButtonProps(nextQuestion, quizApiState, quizLocalState);
    const getPreviousQuestionButtonProps = usePreviousQuestionButtonProps(quizApiState, previousQuestion);
    const getResetQuizButtonProps = useCallback(() => ({
        className: 'cio-question-redo-button',
        type: 'button',
        onClick: () => resetQuiz(),
    }), [resetQuiz]);
    const getHydrateQuizButtonProps = useCallback(() => ({
        className: '',
        type: 'button',
        onClick: () => hydrateQuiz(),
    }), [hydrateQuiz]);
    const getAddToCartButtonProps = useCallback((result, price) => ({
        className: 'cio-result-card-cta-button',
        type: 'button',
        onClick: (e) => addToCart(e, result, price),
    }), [addToCart]);
    const quizResultClickDown = useCallback((event, result, position) => {
        if (event?.key === ' ' || event?.key === 'Enter') {
            if (resultClick) {
                resultClick(result, position);
            }
        }
    }, [resultClick]);
    const getQuizResultButtonProps = useCallback(({ result, position }) => ({
        className: 'cio-result-card-container',
        role: 'button',
        tabIndex: 0,
        onClick: () => resultClick(result, position),
        onKeyDown: (event) => quizResultClickDown(event, result, position),
    }), [quizResultClickDown, resultClick]);
    const getQuizResultLinkProps = useCallback(({ result, position }) => ({
        href: result.data?.url,
        onClick: () => resultClick(result, position),
        onKeyDown: (event) => quizResultClickDown(event, result, position),
    }), [quizResultClickDown, resultClick]);
    const getQuizImageProps = useCallback(() => ({
        src: quizApiState.quizCurrentQuestion?.next_question?.images?.primary_url,
        alt: quizApiState.quizCurrentQuestion?.next_question?.images?.primary_alt,
    }), [quizApiState.quizCurrentQuestion]);
    const getSelectQuestionImageProps = useCallback((option) => ({
        className: 'cio-question-option-image',
        src: option?.images?.primary_url,
        alt: option?.images?.primary_alt,
    }), []);
    return {
        getOpenTextInputProps,
        getNextQuestionButtonProps,
        getPreviousQuestionButtonProps,
        getQuizImageProps,
        getSelectQuestionImageProps,
        getSelectInputProps,
        getCoverQuestionProps,
        getResetQuizButtonProps,
        getHydrateQuizButtonProps,
        getAddToCartButtonProps,
        getQuizResultButtonProps,
        getQuizResultLinkProps,
    };
};
export default usePropsGetters;

==> constructorio-ui-quizzes-1.4.3.tgz: package/lib/mjs/hooks/usePropsGetters/index.js <==
import { useCallback } from 'react';
import useSelectInputProps from './useSelectInputProps';
import useCoverQuestionProps from './useCoverQuestionProps';
import useOpenTextInputProps from './useOpenTextInputProps';
import useNextQuestionButtonProps from './useNextQuestionButtonProps';
import usePreviousQuestionButtonProps from './usePreviousQuestionButtonProps';
const usePropsGetters = (quizEvents, quizApiState, quizLocalState) => {
    const { quizAnswerChanged, nextQuestion, previousQuestion, resetQuiz, hydrateQuiz, addToCart, resultClick, } = quizEvents;
    const getOpenTextInputProps = useOpenTextInputProps(quizAnswerChanged, nextQuestion, quizApiState.quizCurrentQuestion?.next_question, quizLocalState.answerInputs);
    const getCoverQuestionProps = useCoverQuestionProps(quizAnswerChanged, quizApiState.quizCurrentQuestion?.next_question);
    const getSelectInputProps = useSelectInputProps(quizAnswerChanged, nextQuestion, quizApiState.quizCurrentQuestion?.next_question, quizLocalState.answerInputs);
    const getNextQuestionButtonProps = useNextQuestionButtonProps(nextQuestion, quizApiState, quizLocalState);
    const getPreviousQuestionButtonProps = usePreviousQuestionButtonProps(quizApiState, previousQuestion);
    const getResetQuizButtonProps = useCallback((stylesType = 'primary') => ({
        className: stylesType === 'primary' ? 'cio-question-cta-button' : 'cio-question-redo-button',
        type: 'button',
        onClick: () => resetQuiz(),
    }), [resetQuiz]);
    const getHydrateQuizButtonProps = useCallback(() => ({
        className: '',
        type: 'button',
        onClick: () => hydrateQuiz(),
    }), [hydrateQuiz]);
    const getAddToCartButtonProps = useCallback((result, price) => ({
        className: 'cio-result-card-cta-button',
        type: 'button',
        onClick: (e) => addToCart(e, result, price),
    }), [addToCart]);
    const quizResultClickDown = useCallback((event, result, position) => {
        if (event?.key === ' ' || event?.key === 'Enter') {
            if (resultClick) {
                resultClick(result, position);
            }
        }
    }, [resultClick]);
    const getQuizResultButtonProps = useCallback(({ result, position }) => ({
        className: 'cio-result-card-container',
        role: 'button',
        tabIndex: 0,
        onClick: () => resultClick(result, position),
        onKeyDown: (event) => quizResultClickDown(event, result, position),
    }), [quizResultClickDown, resultClick]);
    const getQuizResultLinkProps = useCallback(({ result, position }) => ({
        href: result.data?.url,
        onClick: () => resultClick(result, position),
        onKeyDown: (event) => quizResultClickDown(event, result, position),
    }), [quizResultClickDown, resultClick]);
    const getQuizImageProps = useCallback(() => ({
        src: quizApiState.quizCurrentQuestion?.next_question?.images?.primary_url,
        alt: quizApiState.quizCurrentQuestion?.next_question?.images?.primary_alt,
    }), [quizApiState.quizCurrentQuestion]);
    const getSelectQuestionImageProps = useCallback((option) => ({
        className: 'cio-question-option-image',
        src: option?.images?.primary_url,
        alt: option?.images?.primary_alt,
    }), []);
    return {
        getOpenTextInputProps,
        getNextQuestionButtonProps,
        getPreviousQuestionButtonProps,
        getQuizImageProps,
        getSelectQuestionImageProps,
        getSelectInputProps,
        getCoverQuestionProps,
        getResetQuizButtonProps,
        getHydrateQuizButtonProps,
        getAddToCartButtonProps,
        getQuizResultButtonProps,
        getQuizResultLinkProps,
    };
};
export default usePropsGetters;
